summaryrefslogtreecommitdiff
path: root/helm-ring.el
diff options
context:
space:
mode:
authorThierry Volpiatto <thierry.volpiatto@gmail.com>2017-11-02 09:58:53 +0100
committerThierry Volpiatto <thierry.volpiatto@gmail.com>2017-11-02 10:02:47 +0100
commitb21921768f7b3c3115121050da3285501cdeeebc (patch)
tree467c7a9db480e19e6aa4e038e15ad8c0c8cc5817 /helm-ring.el
parent88894706981b6c62ad60ef4716a07892954ac99d (diff)
Add an error message for unreferenced markers (#1891)
* helm-ring.el (helm-mark-ring-default-action): Do it.
Diffstat (limited to 'helm-ring.el')
-rw-r--r--helm-ring.el5
1 files changed, 3 insertions, 2 deletions
diff --git a/helm-ring.el b/helm-ring.el
index a8589360..79d2c017 100644
--- a/helm-ring.el
+++ b/helm-ring.el
@@ -266,9 +266,10 @@ This is a command for `helm-kill-ring-map'."
(unless helm-yank-point (setq helm-yank-point (point))))
(helm-goto-char target)
(helm-highlight-current-line))
;; marker point to no buffer, no need to dereference it, just
;; delete it.
- (setq mark-ring (delete target mark-ring)))))
+ (setq mark-ring (delete target mark-ring))
+ (error "Marker points to no buffer"))))
(defvar helm-source-mark-ring
(helm-build-sync-source "mark-ring"
@@ -266,9 +266,10 @@ This is a command for `helm-kill-ring-map'."
(helm-goto-char target)
(helm-highlight-current-line))
- ;; marker point to no buffer, no need to dereference it, just
+ ;; marker points to no buffer, no need to dereference it, just
;; delete it.